// Author: Antonio Aloisio <gnuton@gnuton.org>, (C) 2007
// Copyright: See COPYING file that comes with this distribution
//
//
#include <qimage.h>
#include <qpixmap.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qfileinfo.h>
#include <qdir.h>

#include <kurl.h>
#include <klocale.h>
#include <ktempdir.h>
#include <kdebug.h>
#include <kmessagebox.h>

#include "kbloggerimagemanager.h"

KBloggerImageManager::KBloggerImageManager(QDir* tmpDir, QWidget *parent, const char *name)
    :KBloggerImageManagerBlank(parent, name), m_Image(0), m_tempDir(tmpDir)
{
	m_Image=new QImage();
}

void KBloggerImageManager::setImage(const QString& filename)
{
	QImage preview128;//preview 128x128
	m_filename=filename;
	if (! m_Image->load(filename)) return;

	preview128=m_Image->scale(128,128,QImage::ScaleMin);
	imagePreviewLabel->setPixmap ( QPixmap(preview128));

	resizeWidthtLine->setEnabled(false);
	resizeWidthtLine->setText(QString::number(m_Image->width()));
	resizeHeightLine->setText(QString::number(m_Image->height()));

	//Fill infos
	infoHeightLabel->setText(i18n("Height: %1").arg(m_Image->height()));
	infoWidthLabel->setText(i18n("Width: %1").arg(m_Image->width()));
	infoDepthLabel->setText(i18n("Depth: %1").arg(m_Image->depth()));

	infoGraysLabel->setText(i18n("GreyScale: %1").arg( m_Image->isGrayscale()  ));
	infoTransLabel->setText(i18n("Transparency: %1").arg( m_Image->hasAlphaBuffer() ));
}

void KBloggerImageManager::comboSizeChanged(int size)
{
	if ( m_Image->isNull()) return;
	int origWidth, origHeight, blogWidth,modWidth, modHeight;
	origWidth=m_Image->width();
	origHeight=m_Image->height();
	blogWidth=blogWidthLine->text().toInt();

	switch (size)
	{
		case 0: //Original size
		{
			modWidth=origWidth;
			modHeight=origHeight;
		}break;
		case 1: //Big size
		{
			modWidth=blogWidth;
			modHeight=modWidth*origHeight/origWidth;
		}break;
		case 2: //Medium size
		{
			modWidth=blogWidth/2;
			modHeight=modWidth*origHeight/origWidth;
		}break;
		case 3: //Small size
		{
			modWidth=blogWidth/3;
			modHeight=modWidth*origHeight/origWidth;
		}break;
		case 4: //Free size
		{
			resizeWidthtLine->setEnabled(true);
			return;
		}break;
		break;	
	}
	resizeWidthtLine->setEnabled(false);
	resizeWidthtLine->setText(QString::number(modWidth));
	resizeHeightLine->setText(QString::number(modHeight));
}

void KBloggerImageManager::saveResize()
{
	QFileInfo origFile(m_filename);
	KURL scaledImageFilename;
	QImage scaledImage;
	QString ext=origFile.extension();
	scaledImage=m_Image->smoothScale(resizeWidthtLine->text().toInt(),resizeHeightLine->text().toInt());	
	scaledImageFilename.setPath( m_tempDir->path() );
	scaledImageFilename.addPath(origFile.fileName());
	kdDebug() << "KBloggerImageManager::saveResize() file saved:" << scaledImageFilename.path() << endl;
	if (ext.upper()=="JPG") ext="JPEG";
	if (!scaledImage.save(scaledImageFilename.path(),ext.upper()) )
		KMessageBox::sorry ( 0, i18n ( "File %1 not saved" ).arg ( scaledImageFilename.path() ) );
	else
		imageResized(scaledImageFilename.path());
}

void KBloggerImageManager::recalcSize(const QString& width)
{
	int modWidth, modHeight,origHeight, origWidth;
	
	if (m_filename.isNull() ) return;
	origHeight=m_Image->height();
	origWidth=m_Image->width();
	modWidth=resizeWidthtLine->text().toInt();
	modHeight=modWidth*origHeight/origWidth;
	resizeWidthtLine->setText(QString::number(modWidth));
	resizeHeightLine->setText(QString::number(modHeight));
}

void KBloggerImageManager::widthChanged()
{
	comboSizeChanged(resizeComboBox->currentItem());
}


#include "kbloggerimagemanager.moc"
